/**
/// HashTag.Core Library
/// Copyright © 2010-2013
///
/// This module is Copyright © 2010-2013 Steve Powell
/// All rights reserved.
///
/// This library is free software; you can redistribute it and/or
/// modify it under the terms of the Microsoft Public License (Ms-PL)
/// 
/// This library is distributed in the hope that it will be
/// useful, but WITHOUT ANY WARRANTY; without even the implied
/// warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
/// PURPOSE.  See theMicrosoft Public License (Ms-PL) License for more
/// details.
///
/// You should have received a copy of the Microsoft Public License (Ms-PL)
/// License along with this library; if not you may 
/// find it here: http://www.opensource.org/licenses/ms-pl.html
///
/// Steve Powell, hashtagdonet@gmail.com
**/
using System;
using System.Runtime.InteropServices;
using System.Text;
using System.Runtime.Serialization;
namespace ScrimpNet.Collections.Generic
{
	/// <summary>
	/// It's just like a System.Collections.Generic.KeyValuePair,
	/// but the XmlSerializer will serialize the
	/// Key and Value properties!
	/// </summary>
	[Serializable, StructLayout(LayoutKind.Sequential)]
	[DataContract]
	[Citation("http://ianfnelson.com/archives/2006/09/17/a-serializeable-keyvaluepair-class/")]
	public class Property<TKey, TValue>:ICloneable
	{
		private TKey key;
		private TValue value;

		public Property()
		{

		}

		public Property(TKey key,
		TValue value)
		{
			this.key = key;
			this.value = value;
		}
		public override string ToString()
		{
			StringBuilder builder1 = new StringBuilder();
			builder1.Append('[');
			if (this.Key != null)
			{
				builder1.Append(this.Key.ToString());
			}
			builder1.Append(", ");
			if (this.Value != null)
			{
				builder1.Append(this.Value.ToString());
			}
			builder1.Append(']');
			return builder1.ToString();
		}
		/// <summary>
		/// Gets the Value in the Key/Value Pair
		/// </summary>
		[DataMember]
		public TValue Value
		{
			get
			{
				return this.value;
			}
			set
			{
				this.value = value;
			}
		}
		/// <summary>
		/// Gets the Key in the Key/Value pair
		/// </summary>
		[DataMember]
		public TKey Key
		{
			get
			{
				return this.key;
			}
			set
			{
				this.key = value;
			}
		}

		public object Clone()
		{
			return new Property<TKey,TValue>(this.key, this.value);
		}
	}
}