/**
/// HashTag.Core Library
/// Copyright © 2010-2013
///
/// This module is Copyright © 2010-2013 Steve Powell
/// All rights reserved.
///
/// This library is free software; you can redistribute it and/or
/// modify it under the terms of the Microsoft Public License (Ms-PL)
/// 
/// This library is distributed in the hope that it will be
/// useful, but WITHOUT ANY WARRANTY; without even the implied
/// warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
/// PURPOSE.  See theMicrosoft Public License (Ms-PL) License for more
/// details.
///
/// You should have received a copy of the Microsoft Public License (Ms-PL)
/// License along with this library; if not you may 
/// find it here: http://www.opensource.org/licenses/ms-pl.html
///
/// Steve Powell, hashtagdonet@gmail.com
**/
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Configuration;

namespace HashTag
{
    public static partial class CoreConfig
    {
        /// <summary>
        /// Values to bootstrap configuration providers
        /// </summary>
        public class Configuration
        {
            /// <summary>
            /// Fully qualified name of assembly ('type','assembly') that will provide external configuration data to application. Assembly must implement IInternalConfigSystem. (Key: HashTag.Configuration.ExternalSource)
            /// </summary>
            /// <remarks>
            /// Used ConfigurationManager reference instead of HashTag.ConfigManager since this value is read at library bootstrapping time and ConfigManager isn't fully initialized
            /// </remarks>
            public static string ExternalSource
            {
                get
                {
                    string configSource = ConfigurationManager.AppSettings["HashTag.Configuration.ExternalSource"];
                    if (configSource == null || string.IsNullOrEmpty(configSource) == true)
                    {
                        HashTag.Diagnostics.Log.LastChanceLog(Diagnostics.MessageLevel.Warning, "Unable to find <appSettings> key 'HashTag.Configuration.ExternalSource'.  External configuration source might be disabled");
                    }
                    return configSource;
                }
            }

            /// <summary>
            /// Url for connecting WcfConfigSystem to WCF server (Required: HashTag.Configuration.WcfServiceUrl)
            /// </summary>
            /// <remarks>
            /// Used ConfigurationManager reference instead of HashTag.ConfigManager since this value is read at library bootstrapping time and ConfigManager isn't fully initialized
            /// </remarks>
            public static string WcfUrl
            {
                get
                {
                    string url = ConfigurationManager.AppSettings["HashTag.Configuration.WcfServiceUrl"];
                    if (url == null || string.IsNullOrEmpty(url) == true)
                    {
                        string msg = "Unable to find <appSettings> key 'HashTag.Configuration.WcfServiceUrl'";
                        Diagnostics.Log.LastChanceLog(Diagnostics.MessageLevel.Error, msg);
                        throw new ConfigurationErrorsException(msg);
                    }
                    return url;
                }
            }

            /// <summary>
            /// String of characters the delimits the beginning of a meta data lookup field (Constant: '{%')
            /// </summary>
            public static string StartToken
            {
                get
                {
                    return "{%";
                }
            }
            /// <summary>
            /// String of characters the delimits the ending of a meta data lookup field (Constant: '%}')
            /// </summary>
            public static string StopToken
            {
                get
                {
                    return "%}";
                }
            }
        }
    }
}