/**
/// HashTag.Core Library
/// Copyright © 2010-2013
///
/// This module is Copyright © 2010-2013 Steve Powell
/// All rights reserved.
///
/// This library is free software; you can redistribute it and/or
/// modify it under the terms of the Microsoft Public License (Ms-PL)
/// 
/// This library is distributed in the hope that it will be
/// useful, but WITHOUT ANY WARRANTY; without even the implied
/// warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
/// PURPOSE.  See theMicrosoft Public License (Ms-PL) License for more
/// details.
///
/// You should have received a copy of the Microsoft Public License (Ms-PL)
/// License along with this library; if not you may 
/// find it here: http://www.opensource.org/licenses/ms-pl.html
///
/// Steve Powell, hashtagdonet@gmail.com
**/
using HashTag.Text;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace HashTag.Diagnostics
{
    public class LogMessageBuilder
    {
        internal LogMessageBuilder(LogMessage rootMessage)
        {
            _message = rootMessage;
        }

        private LogMessage _message;

        public void Write()
        {
            _message.Write();
        }
        public void Write(string messageText, params object[] args)
        {
            _message.MessageText = TextUtils.StringFormat(messageText, args);
            _message.Write();
        }

        public LogMessageBuilder WithId(int eventId)
        {
            _message.MessageCode = eventId.ToString();
            return this;
        }
        public LogMessageBuilder WithCode(string eventCode)
        {
            _message.MessageCode = eventCode;
            return this;
        }

        /// <summary>
        /// Set sub application key
        /// </summary>
        /// <param name="moduleName"></param>
        /// <returns></returns>
        public LogMessageBuilder ForModule(string moduleName)
        {
            _message.ApplicationSubKey = moduleName;
            return this;
        }

        /// <summary>
        /// Add a name to a group
        /// </summary>
        /// <param name="groupName"></param>
        /// <returns></returns>
        public LogMessageBuilder InGroup(string groupName)
        {
            _message.Categories.Add(groupName);
            return this;
        }


        public LogMessageBuilder Collect(string key, object value) // extended properties
        {
            _message.ExtendedProperties.Add(key, value.ToString());
            return this;
        }

        public LogMessageBuilder Catch(Exception ex)
        {
            _message.AddException(ex);
            return this;
        }

        public LogMessageBuilder CaptureHttp(HttpCaptureFlags flags= HttpCaptureFlags.Form)
        {

            return this;
        }

        public LogMessageBuilder CaptureMachineContext()
        {
            return this;
        }

        public LogMessageBuilder CaptureUser()
        {
            return this;
        }

        public LogMessageBuilder OnChannel(string channelName)
        {
            _message.Channel = channelName;
            return this;
        }

        /// <summary>
        /// Returns a reference to the backing message that is being built up
        /// </summary>
        /// <returns></returns>
        public LogMessage Think()
        {
            return _message;
        }

        [EditorBrowsableAttribute(EditorBrowsableState.Never)]
        public override string ToString()
        {
            return base.ToString();
        }

        [EditorBrowsableAttribute(EditorBrowsableState.Never)]
        public override bool Equals(object obj)
        {
            return base.Equals(obj);
        }
        [EditorBrowsableAttribute(EditorBrowsableState.Never)]
        public override int GetHashCode()
        {
            return base.GetHashCode();
        }
    }

}